# resPYte
Ha, rest -> respite but in python resPYte .. ha..

# WHY
haven't you ever thought "Hey I'd like a Postman like client, but I really really really don't wanna install node because like... why should I? also I don't need a GUI I have a terminal!"?

.. no? Oh well, I have.


# What is it?
super basic TUI for testing REST endpoint. Literally built it in like .. an hour.. I might have spent more time on the name.. (probably bugs)

anywho..
